pub enum DatumComponent {
Axis(FrameAxis),
Plane(FrameAxis),
}Expand description
A part of a frame datum that can be used on its own. Its origin is not one: the frame as a whole is used as its origin already.
Variants
Axis(FrameAxis)
One of its axes.
Plane(FrameAxis)
The plane normal to one of its axes: Plane(Z) is its xy plane.